bgpview-cli-0.1.0 is not a library.
BGPView CLI
Working in progress, only ip sub command usable for now.
Other sub commands can be added easily, but I do not use them personally, so they may not be added forever if no one asks.
You can refer to the document of bgpview.io API if you want to contribute or implement other commands.
Install
Usage
Use -h/--help for help.
You can set alias if you use some command very often, bash for example:
License
See UNLICENSE.